<?php
if ( ! function_exists( 'inspiry_demo_import_files' ) ) :

	/**
	 * Demo contents files path
	 */
	function inspiry_demo_import_files() {
		return array(
			array(
				'import_file_name'         => esc_html__( 'Elegantia Demo Content Import', 'framework' ),
				'local_import_file'        => trailingslashit( get_template_directory() ) . 'include/demo-import/import-files/demo-content.xml',
				'local_import_widget_file' => trailingslashit( get_template_directory() ) . 'include/demo-import/import-files/widgets.wie',
				'import_preview_image_url' => get_stylesheet_directory_uri() . '/screenshot.png',
				'import_notice'            => htmlspecialchars_decode( esc_html__( 'After you import this demo, you will have to setup the permalinks settings to <strong>Post name</strong> from <code>Settings > Permalinks</code> page.', 'framework' ) ),
			)
		);
	}

	add_filter( 'pt-ocdi/import_files', 'inspiry_demo_import_files' );
endif;


if ( ! function_exists( 'inspiry_plugin_page_setup' ) ) :

	/**
	 * Elegantia demo import page setup
	 */
	function inspiry_plugin_page_setup( $default_settings ) {
		$default_settings['parent_slug'] = 'themes.php';
		$default_settings['page_title']  = esc_html__( 'Elegantia Demo Import', 'framework' );
		$default_settings['menu_title']  = esc_html__( 'Elegantia Demo Import', 'framework' );
		$default_settings['capability']  = 'import';
		$default_settings['menu_slug']   = 'elegantia-demo-import';

		return $default_settings;
	}

	add_filter( 'pt-ocdi/plugin_page_setup', 'inspiry_plugin_page_setup' );
endif;


if ( ! function_exists( 'inspiry_after_import_setup' ) ) :

	/**
	 * Imported contents settings
	 */
	function inspiry_after_import_setup() {

		// Assign menu to its location.
		$left_main_menu  = get_term_by( 'name', 'Left Main Menu', 'nav_menu' );
		$right_main_menu = get_term_by( 'name', 'Right Main Menu', 'nav_menu' );
		$footer_menu     = get_term_by( 'name', 'Footer Menu', 'nav_menu' );

		if ( $left_main_menu || $right_main_menu || $footer_menu ) {
			set_theme_mod( 'nav_menu_locations', array(
				'left-main-menu'  => $left_main_menu->term_id,
				'right-main-menu' => $right_main_menu->term_id,
				'footer-menu'     => $footer_menu->term_id,
			) );
		}

		// Set homepage as front page and blog page as posts page
		$home_page = get_page_by_title( 'Home' );
		$blog_page = get_page_by_title( 'Blog' );

		if ( $home_page || $blog_page ) {
			update_option( 'show_on_front', 'page' );
		}

		if ( $home_page ) {
			update_option( 'page_on_front', $home_page->ID );
		}

		if ( $blog_page ) {
			update_option( 'page_for_posts', $blog_page->ID );
		}

		// slider and home section demo images
		$demo_theme_images = inspiry_get_demo_images();

		// basic theme options configuration
		$demo_theme_options = array(
			"theme_1_slide_img"              => $demo_theme_images['slider_image_1'],
			"theme_2_slide_img"              => $demo_theme_images['slider_image_2'],
			"theme_3_slide_img"              => $demo_theme_images['slider_image_3'],
			"theme_1_column_img"             => $demo_theme_images['home_image_1'],
			"theme_2_column_img"             => $demo_theme_images['home_image_2'],
			"theme_3_column_img"             => $demo_theme_images['home_image_3'],
			"theme_address_text"             => __( "Las Angeles, AV 123456 - 123.456.7800", "framework" ),
			"theme_reservation_text"         => __( "Call 023 7526 8539  or Make Online Reservation", "framework" ),
			"theme_reservation_button_text"  => __( "MAKE  RESERVATION NOW", "framework" ),
			"theme_reservation_button_link"  => __( "#", "framework" ),
			"theme_1_slide_link"             => __( "#", "framework" ),
			"theme_2_slide_link"             => __( "#", "framework" ),
			"theme_3_slide_link"             => __( "#", "framework" ),
			"theme_4_slide_link"             => __( "#", "framework" ),
			"theme_5_slide_link"             => __( "#", "framework" ),
			"theme_display_three_columns"    => "true",
			"theme_1_column_heading"         => __( 'About Elegantia', 'framework' ),
			"theme_1_column_sub_heading"     => __( 'Elegantia Introduction', 'framework' ),
			"theme_1_column_text"            => "Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes Lorem lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem Lorem lectorum. Mirum est notare quam littera gothica.",
			"theme_1_column_link_txt"        => __( 'READ MORE', 'framework' ),
			"theme_1_column_link"            => "#",
			"theme_2_column_heading"         => __( 'Our Menu', 'framework' ),
			"theme_2_column_sub_heading"     => __( 'Elegantia Food', 'framework' ),
			"theme_2_column_text"            => "Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes Lorem lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem Lorem lectorum. Mirum est notare quam littera gothica.",
			"theme_2_column_link_txt"        => __( 'READ MORE', 'framework' ),
			"theme_2_column_link"            => "#",
			"theme_3_column_heading"         => __( 'Special Events', 'framework' ),
			"theme_3_column_sub_heading"     => __( 'Elegantia Events', 'framework' ),
			"theme_3_column_text"            => "Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes Lorem lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem Lorem lectorum. Mirum est notare quam littera gothica.",
			"theme_3_column_link_txt"        => __( 'READ MORE', 'framework' ),
			"theme_3_column_link"            => "#",
			"theme_display_menu_items"       => "true",
			"theme_testimonial_text"         => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent tempor mattis tempus. Phasellus ullamcorper elementum diam non laoreet. Cras gravida, nisl vitae consectetur porta, metus elit luctus nulla, nec interdum ligula ante in est. Phasellus semper pretium tellus.",
			"theme_testimonial_author"       => "John Doe",
			"theme_body_text_color"          => "#909090",
			"theme_body_headings_color"      => "#824328",
			"theme_selection_bg_color"       => "#f8dda8",
			"theme_link_color"               => "#d3af80",
			"theme_link_hover_color"         => "#824328",
			"theme_show_social_menu"         => "true",
			"theme_facebook_link"            => "#",
			"theme_twitter_link"             => "#",
			"theme_mail_link"                => "#",
			"theme_google_link"              => "#",
			"theme_linked_link"              => "#",
			"theme_pinterest_link"           => "#",
			"theme_instagram_link"           => "#",
			"theme_yahoo_link"               => "#",
			"theme_vk_link"                  => "#",
			"theme_rss_link"                 => "#",
			"theme_blog_title"               => __( "Our News", "framework" ),
			"theme_use_lightbox"             => "true",
			"theme_menu_title"               => __( "Our Menu", "framework" ),
			"theme_menu_use_lightbox"        => "true",
			"theme_event_title"              => __( "Special Events", "framework" ),
			"theme_event_use_lightbox"       => "true",
			"theme_gmap_lati"                => "48.857976",
			"theme_gmap_longi"               => "2.29497",
			"theme_gmap_zoom"                => "17",
			"theme_contact_form_heading"     => __( "Contact Us", "framework" ),
			"theme_contact_form_text"        => __( "Fill out the form below to send us a message and we will get back to you ASAP.", "framework" ),
			"theme_reservation_form_heading" => __( "Make Reservation Now", "framework" ),
			"theme_reservation_form_text"    => __( "Fill out the form below to make reservation", "framework" ),
			"theme_footer_address_text"      => "12300 Las Angeles Main Blvd, Las Angeles, AV 123456 - 123.456.7890",
			"theme_copyright_text"           => "Copyright &copy; 2012 Elegantia Restaurant &amp; Bar. All rights reserved.",
		);

		// loop over all options in array and update the options table in database.
		foreach ( $demo_theme_options as $key => $value ) {
			$existing_value = get_option( $key );
			if ( empty( $existing_value ) ) {
				update_option( $key, $value );
			}
		}
	}

	add_action( 'pt-ocdi/after_import', 'inspiry_after_import_setup' );
endif;


if ( ! function_exists( 'inspiry_get_demo_images' ) ) :
	function inspiry_get_demo_images() {

		$demo_images = array();
		$demo_data   = array(
			'slider_image_1' => 'Slider Image One',
			'slider_image_2' => 'Slider Image Two',
			'slider_image_3' => 'Slider Image Three',
			'home_image_1'   => 'Home Column One',
			'home_image_2'   => 'Home Column Two',
			'home_image_3'   => 'Home Column Three',
		);

		foreach ( $demo_data as $key => $title ) {
			$attachment = get_page_by_title( $title, OBJECT, 'attachment' );

			if ( $attachment ) {
				$demo_images[ $key ] = wp_get_attachment_url( $attachment->ID );
			}
		}

		return $demo_images;
	}
endif;